@@ -1,3 +1,4 @@
+# pylint: disable=R1732
 #  Drakkar-Software OctoBot
 #  Copyright (c) Drakkar-Software, All rights reserved.
 #
@@ -67,6 +68,25 @@ def get_os():
     return enums.PlatformsName(os.name)
 
 
+def is_machine_64bit() -> bool:
+    """
+    Win: AMD64
+    Debian-64: x86_64
+    From https://stackoverflow.com/questions/2208828/detect-64bit-os-windows-in-python
+    :return: True if the machine is 64bit
+    """
+    return platform.machine().endswith("64")
+
+
+def is_arm_machine() -> bool:
+    """
+    Can be armv7l or aarch64 (raspberry, Android smartphone...)
+    From https://raspberrypi.stackexchange.com/questions/5100/detect-that-a-python-program-is-running-on-the-pi
+    :return: True if the machine is 64bit
+    """
+    return platform.machine() in ["armv7l", "aarch64"]
+
+
 def _is_on_docker():
     """
     Check if the current platform is docker
